@@ -395,7 +395,17 @@ def stepbd(t, d):
 
 
 @check_pen
-def row(t, func, size):
+def _flashrow(t, func, size, sp=0.6):
+    turtle.tracer(0)
+    while True:
+        row(t, func, size)
+        turtle.update()
+        time.sleep(sp)
+        t.clear()
+
+
+@check_pen
+def _row(t, func, size):
     '''
     绘制一行高低略有不同的图案，绘制的图案取决于传入的绘图函数名称
     一行中图案的数量计算，取决于图案的大小和画笔所在位置
@@ -409,14 +419,14 @@ def row(t, func, size):
     y = t.ycor()
     y0 = y + randint(-5, 5)
     move(t, x, y0)
-    # t0 = t.clone()
-    if x > 0: x *= -1
+
     sw = turtle.getscreen().window_width()
+
     sh = turtle.getscreen().window_height()
-    margin = sw / 2 - abs(x)
-    nums = int(min(10, (sw - 2 * margin) // (size * 2)))
+    nums = int(min(8, (sw - x) // (size * 4)))
+    print(sw, nums)
     if nums != 0:
-        step = (sw - 2 * margin) // nums
+        step = (sw - x) // (nums * 2)
 
     if nums == 0:
         func(t, size)
@@ -429,7 +439,15 @@ def row(t, func, size):
     t.pd()
 
 
-def getpen():
+@check_pen
+def row(t, func, size, anim=False):
+    if anim:
+        _flashrow(t, func, size)
+    else:
+        _row(t, func, size)
+
+
+def getpen(color='black'):
     '''
     获得一支画笔
 
@@ -452,6 +470,7 @@ def getpen():
         'mb': (0, -SCR_H / 2)
     }
     t.ht()
+    t.color(color)
     t.speed(0)
     return t
 
